@@ -61,10 +61,8 @@ class Colour:
 
 class MinecraftIcons(Enum):
     GRASS_BLOCK = 1
-    GRASSBLOCK = 1  # alias
     DIAMOND = 2
     DIAMOND_SWORD = 3
-    DIAMONDSWORD = 3  # alias
     CREEPER = 4
     PIG = 5
     TNT = 6
@@ -75,7 +73,6 @@ class MinecraftIcons(Enum):
     SIGN = 11
     RAIL = 12
     CRAFTING_BENCH = 13
-    CRAFTINGBENCH = 13  # alias
     REDSTONE = 14
     FIRE = 15
     COBWEB = 16
@@ -83,53 +80,58 @@ class MinecraftIcons(Enum):
     FURNACE = 18
     BOOK = 19
     STONE_BLOCK = 20
-    STONEBLOCK = 20  # alias
     WOODEN_PLANK_BLOCK = 21
-    WOODENPLANKBLOCK = 21  # alias
     IRON_INGOT = 22
-    IRONINGOT = 22  # alias
     GOLD_INGOT = 23
-    GOLDINGOT = 23  # alias
     WOODEN_DOOR = 24
-    WOODENDOOR = 24  # alias
     IRON_DOOR = 25
-    IRONDOOR = 25  # alias
     DIAMOND_CHESTPLATE = 26
-    DIAMONDCHESTPLATE = 26  # alias
     FLINT_AND_STEEL = 27
-    FLINTANDSTEEL = 27  # alias
     GLASS_BOTTLE = 28
-    GLASSBOTTLE = 28  # alias
     SPLASH_POTION = 29
-    SPLASHPOTION = 29  # alias
     CREEPER_SPAWNEGG = 30
-    CREEPERSPAWNEGG = 38  # alias
     COAL = 31
     IRON_SWORD = 32
-    IRONSWORD = 32  # alias
     BOW = 33
     ARROW = 34
     IRON_CHESTPLATE = 35
-    IRONCHESTPLATE = 35  # alias
     BUCKET = 36
     BUCKET_WITH_WATER = 37
-    BUCKETWITHWATER = 37  # alias
     BUCKET_WITH_LAVA = 38
-    BUCKETWITHLAVA = 38  # alias
     BUCKET_WITH_MILK = 39
-    BUCKETWITHMILK = 39  # alias
-    diamond_boots = 40
-    DIAMONDBOOTS = 40  # alias
+    DIAMOND_BOOTS = 40
     WOODEN_HOE = 41
-    WOODENHOE = 41  # alias
     BREAD = 42
     WOODEN_SWORD = 43
-    WOORDENSWORD = 43  # alias
     BONE = 44
     OAK_LOG = 45
-    OAKLOG = 45  # alias
     RANDOM = 46
 
+    # ALIASES -------------------
+    GRASSBLOCK = 1
+    DIAMONDSWORD = 3
+    CRAFTINGBENCH = 13
+    STONEBLOCK = 20
+    WOODENPLANKBLOCK = 21
+    IRONINGOT = 22
+    GOLDINGOT = 23
+    WOODENDOOR = 24
+    IRONDOOR = 25
+    DIAMONDCHESTPLATE = 26
+    FLINTANDSTEEL = 27
+    GLASSBOTTLE = 28
+    SPLASHPOTION = 29
+    CREEPERSPAWNEGG = 38
+    IRONSWORD = 32
+    IRONCHESTPLATE = 35
+    BUCKETWITHWATER = 37
+    BUCKETWITHLAVA = 38
+    BUCKETWITHMILK = 39
+    DIAMONDBOOTS = 40
+    WOODENHOE = 41
+    WOORDENSWORD = 43
+    OAKLOG = 45
+
 
 class Filters(Enum):
     BLUR = 1
