@@ -186,7 +186,10 @@ class Client:
         return Image(str(response.url), response)
 
     async def drake(self, top: str, bottom: str, *, ayano: bool = False) -> Image:
-        response = await self._api_request("drake", {"top": str(top), "bottom": str(bottom), "ayano": bool(ayano)})
+        params = {"top": str(top), "bottom": str(bottom)}
+        if ayano:
+            params["ayano"] = bool(ayano)
+        response = await self._api_request("drake", params)
         return Image(str(response.url), response)
 
     async def facts(self, text: str) -> Image:
@@ -228,7 +231,7 @@ class Client:
         return Image(str(response.url), response)
 
     async def pornhub(self, text: str, text2: str) -> Image:
-        response = await self._api_request("pornhub", {"text": str(text), "text2": str(text)})
+        response = await self._api_request("pornhub", {"text": str(text), "text2": str(text2)})
         return Image(str(response.url), response)
 
     async def salty(self, image: str) -> Image:
